import { ImmutableDirectory, TreeNode, Opts as NodeOpts } from "./TreeNode";
import { BidirectionalMap } from "../BidirectionalMap";
import { Id } from "../Id";
export declare const ROOT_ID: Id;
export type JSONNode = NodeOpts;
export declare class Tree {
    /** Tree nodes indexed by id. */
    nodes: Map<Id, TreeNode>;
    /**
     * Parent id to child id index.
     * Allows lookups of children by name or child id.
     */
    children: Map<Id, BidirectionalMap<Id, string>>;
    constructor();
    /** Create a new root node. */
    private createRootNode;
    /** The workspace's root directory. */
    get root(): ImmutableDirectory;
    /** Get a node by its id. */
    getNodeById(id: Id): TreeNode | undefined;
    /** Get a node's id with the given path. */
    getIdFromPath(path: string): Id | undefined;
    /** Get a node with the given path. */
    getNodeFromPath(path: string): TreeNode | undefined;
    /** Move the provided node id to the given parent id. */
    moveNode(id: Id, parentId: Id, name?: string): TreeNode;
    /** Delete the node with the given id. */
    deleteNode(id: Id): void;
    /** Add a node to the tree. */
    _addNode(node: TreeNode): void;
    /** Add JSON Nodes to the tree. */
    _addJSONNodes(nodes: JSONNode[]): void;
    /** Add a node to the tree. */
    _addJSONNode(node: JSONNode): void;
    /** Add a parent-child relation to the tree. */
    _addChild(node: TreeNode, parentId: Id): void;
    /** Recursively remove a node and all its children. */
    _removeNode(node: TreeNode): void;
    /** Remove a node's parent-child relation from the tree. */
    _removeChild(node: TreeNode): void;
    /** Serialize a Tree to JSON. */
    toJSON(): JSONNode[];
    /** Deserialize a Tree from JSON. */
    static fromJSON(nodes: JSONNode[]): Tree;
}
