export interface ContextualErrorOptions<Code> {
    /** Code of the error that describes what kind of operation failed. */
    code: Code;
    /** User-facing error message. */
    publicMessage: string;
    /** Original (internal) error instance. */
    error: Error;
}
export declare class ContextualError<Code, Context = never> extends Error {
    readonly code: Code;
    /** Parent operation context. */
    context?: Context;
    readonly error: Error;
    readonly publicMessage: string;
    constructor(options: ContextualErrorOptions<Code>);
    /**
     * Extend this error with a parental context.
     * @param context Parental context.
     * @example
     * const error = new ContextualError({
     *   code: 'GIT_PULL_REJECTED',
     *   details,
     * })
     * error.setContext('GIT_COMMIT')
     */
    setContext(context: Context): this;
}
