import { Disposable, IDisposable } from "./Disposable";
export type RequestHandlerFn = (method: string, params: any) => Promise<any>;
export type NotificationHandlerFn = (method: string, data: any) => Promise<any>;
export type ErrorHandlerFn = (error: Error) => Promise<any>;
export interface MessageEndpoint {
    send(message: any): void;
    onMessage(cb: (msg: any) => void): IDisposable;
    onError(cb: (err: any) => void): IDisposable;
}
export interface WorkerMessageBusOpts {
    /** name for the channel */
    channel: string;
    endpoint: MessageEndpoint;
    handleRequest: RequestHandlerFn;
    handleNotification: NotificationHandlerFn;
    handleError: ErrorHandlerFn;
    timeoutMs: number;
}
export interface PendingRequest {
    resolve: (result: any) => void;
    reject: (err: Error) => void;
}
export declare class WorkerMessageBus extends Disposable {
    private endpoint;
    private handleRequest;
    private handleNotification;
    private handleError;
    private channel;
    private timeoutMs;
    private pendingRequests;
    private _messageId;
    constructor(opts: WorkerMessageBusOpts);
    nextMessageId(): number;
    request(method: string, params: any): Promise<any>;
}
