import { TextOperation } from "./TextOperation";
/**
 * Enables code editors that asynchronously applies server operations and emits events for
 * applied server operations, AKA VSCode, to work with the OT Client.
 */
export declare class AsyncDocument {
    private queue;
    private bufferedDocument;
    private pendingServerOperations;
    constructor(document: string);
    get document(): string;
    get hasPendingServerOperations(): boolean;
    /**
     * Applies the operation to the buffered document and returns the transformed
     * operation to be applied to the OT Client
     */
    applyClientOperation(operation: TextOperation): TextOperation | void;
    /**
     * Adds the operation to the queue and calls the callback with the current
     * buffered document and the transformed operation to be applied to the
     * code editor. The callback should throw an error when applying the operation
     * to the code editor fails. The promise returned will reject after X retries
     */
    applyServerOperation(operation: TextOperation, cb: (document: string, transformedOperation: TextOperation) => Promise<void>): Promise<void>;
}
