import { OperationBuffer } from "./OperationBuffer";
import { TextOperation } from "./TextOperation";
export declare class Server {
    document: string;
    clientRevisions: Map<string, number>;
    operationBuffer: OperationBuffer;
    /**
     * Create a server instance, provided a document as a string and an array of
     * operations.
     */
    constructor(document: string);
    /** Get the current server revision of the document */
    get revision(): number;
    /** Call this whenever a client disconnects from the server, this cleans up their data */
    addClient(clientId: string, revision: number): void;
    /** Call this whenever a client disconnects from the server, this cleans up their data */
    removeClient(clientId: string): void;
    /** Use this to get the client's ot state */
    getClientRevision(clientId: string): number | null;
    /** Call this whenever a client acknowledges a server operation */
    ack(clientId: string, revision: number): void;
    /**
     * This will clear as many operations as possible. Meaning that clients
     * on older revisions will still stay in history so we can still transform
     * their incoming operations
     */
    clearOperations(): void;
    getOperations(): TextOperation[];
    /** Call this method whenever you receive an operation from a client. */
    receiveOperation(revision: number, operation: TextOperation): TextOperation;
    /** Call this method whenever you want to apply a server-generated operation. */
    applyOperation(operation: TextOperation): void;
}
