export type RawOperation = number | string;
export type JSONTextOperation = Array<RawOperation>;
export declare class TextOperation {
    ops: RawOperation[];
    baseLength: number;
    targetLength: number;
    /**
     * Transform takes two operations A and B that happened concurrently and
     * produces two operations A' and B' (in an array) such that
     * `apply(apply(S, A), B') = apply(apply(S, B), A')`. This function is the
     * heart of OT.
     */
    static transform(operation1: TextOperation, operation2: TextOperation): [TextOperation, TextOperation];
    static isRetain(op: RawOperation): op is number;
    static isInsert(op: RawOperation): op is string;
    static isDelete(op: RawOperation): op is number;
    static fromJSON(ops: RawOperation[]): TextOperation;
    invert(str: string): TextOperation;
    equals(other: TextOperation): boolean;
    retain(n: number): TextOperation;
    insert(str: string): TextOperation;
    delete(n: string | number): TextOperation;
    isNoop(): boolean;
    apply(str: string): string;
    /**
     * Compose merges two consecutive operations into one operation, that
     * preserves the changes of both. Or, in other words, for each input string S
     * and a pair of consecutive operations A and B,
     * apply(apply(S, A), B) = apply(S, compose(A, B)) must hold.
     */
    compose(operation2: TextOperation): TextOperation;
    toString(): string;
    toJSON(): JSONTextOperation;
}
