export declare class AbortError extends Error {
    originalError: Error;
    constructor(message: string | Error);
}
export type DecoratedError = Error & {
    attemptNumber: number;
    retriesLeft: number;
};
export type RunPromiseFn<T> = (attemptNumber: number) => Promise<T>;
export interface PromiseRetryOptions {
    /** The maximum amount of times to retry the operation, defaults to 10 */
    retries?: number;
    /** The exponential factor to use, defaults to 2 */
    factor?: number;
    /** The number of milliseconds before starting the first retry, defaults to 1000 */
    minTimeout?: number;
    /** The maximum number of milliseconds between two retries, defaults to 10 000 */
    maxTimeout?: number;
    /** Randomizes the timeouts by multiplying with a factor between 1 to 2, defaults to true */
    randomize?: boolean;
    /** A callback to be called on failed attempt, mainly used for debugging/logging */
    onFailedAttempt?: (error: Error) => void;
}
/**
 * Runs a promise callback and retries it according to the provided retry configuration until it succeeds or
 * has used up all it's retry attempts, you can also abort early using the pRetry.AbortError
 * */
export declare function run<T>(input: RunPromiseFn<T>, options?: PromiseRetryOptions): Promise<T>;
